@@ -106,79 +106,82 @@
     </message>
 </context>
 <context>
-    <name>AxisTicsOptionWidget</name>
+    <name>AxisTics</name>
     <message>
-        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="32"/>
-        <source>Tics</source>
-        <translation>目盛り</translation>
-    </message>
-    <message>
-        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="65"/>
-        <source>Ac&amp;tivation</source>
-        <translation>有効化(&amp;T)</translation>
-    </message>
-    <message>
-        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="70"/>
+        <location filename="opt/AxisTics.cpp" line="30"/>
         <source>border</source>
         <translation>縁</translation>
     </message>
     <message>
-        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="71"/>
+        <location filename="opt/AxisTics.cpp" line="31"/>
         <source>axis</source>
         <translation>軸</translation>
     </message>
+</context>
+<context>
+    <name>AxisTicsOptionWidget</name>
     <message>
-        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="76"/>
+        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="33"/>
+        <source>Tics</source>
+        <translation>目盛り</translation>
+    </message>
+    <message>
+        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="66"/>
+        <source>Ac&amp;tivation</source>
+        <translation>有効化(&amp;T)</translation>
+    </message>
+    <message>
+        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="79"/>
         <source>&amp;Mirroring</source>
         <translation>ミラー(&amp;M)</translation>
     </message>
     <message>
-        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="81"/>
+        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="84"/>
         <source>&amp;Rotation</source>
         <translation>回転(&amp;R)</translation>
     </message>
     <message>
-        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="90"/>
+        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="93"/>
         <source>&amp;Start:</source>
         <translation>開始(&amp;S):</translation>
     </message>
     <message>
-        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="98"/>
+        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="101"/>
         <source>&amp;Increment:</source>
         <translation>増分(&amp;I):</translation>
     </message>
     <message>
-        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="106"/>
+        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="109"/>
         <source>&amp;End:</source>
         <translation>終了(&amp;E):</translation>
     </message>
     <message>
-        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="169"/>
+        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="172"/>
         <source>&amp;Position</source>
         <translation>位置(&amp;P)</translation>
     </message>
     <message>
-        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="170"/>
+        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="173"/>
         <source>O&amp;thers</source>
         <translation>その他(&amp;T)</translation>
     </message>
     <message>
-        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="33"/>
+        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="34"/>
         <source>set &lt;i&gt;axis&lt;/i&gt;tics</source>
         <translation>set &lt;i&gt;軸&lt;/i&gt; tics</translation>
     </message>
     <message>
-        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="139"/>
+        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="142"/>
         <source>Auto</source>
         <translation>自動</translation>
     </message>
     <message>
-        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="140"/>
+        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="143"/>
         <source>Start/Increment/End</source>
         <translation>開始/増分/終了</translation>
     </message>
     <message>
-        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="141"/>
+        <location filename="gui/opt/AxisTicsOptionWidget.cpp" line="144"/>
         <source>Labels/Positions</source>
         <translation>ラベル/位置</translation>
     </message>
@@ -250,6 +253,22 @@
         <translation>ダミー変数</translation>
     </message>
 </context>
+<context>
+    <name>Encoding</name>
+    <message>
+        <location filename="opt/Encoding.cpp" line="22"/>
+        <source>default</source>
+        <translation>標準設定</translation>
+    </message>
+</context>
+<context>
+    <name>EncodingOptionWidget</name>
+    <message>
+        <location filename="gui/opt/EncodingOptionWidget.cpp" line="29"/>
+        <source>Encoding</source>
+        <translation>エンコーディング</translation>
+    </message>
+</context>
 <context>
     <name>FitBasicWidget</name>
     <message>
@@ -506,100 +525,133 @@
         <translation> 軸</translation>
     </message>
 </context>
+<context>
+    <name>Key</name>
+    <message>
+        <location filename="opt/Key.cpp" line="30"/>
+        <source>left</source>
+        <translation>左</translation>
+    </message>
+    <message>
+        <location filename="opt/Key.cpp" line="31"/>
+        <source>right</source>
+        <translation>右</translation>
+    </message>
+    <message>
+        <location filename="opt/Key.cpp" line="32"/>
+        <source>top</source>
+        <translation>上</translation>
+    </message>
+    <message>
+        <location filename="opt/Key.cpp" line="33"/>
+        <source>bottom</source>
+        <translation>中の下</translation>
+    </message>
+    <message>
+        <location filename="opt/Key.cpp" line="34"/>
+        <source>outside</source>
+        <translation>外側</translation>
+    </message>
+    <message>
+        <location filename="opt/Key.cpp" line="35"/>
+        <source>below</source>
+        <translation>外の下</translation>
+    </message>
+</context>
 <context>
     <name>KeyOptionWidget</name>
     <message>
-        <location filename="gui/opt/KeyOptionWidget.cpp" line="121"/>
+        <location filename="gui/opt/KeyOptionWidget.cpp" line="120"/>
         <source>Left Justify</source>
         <translation>左寄せ</translation>
     </message>
     <message>
-        <location filename="gui/opt/KeyOptionWidget.cpp" line="126"/>
+        <location filename="gui/opt/KeyOptionWidget.cpp" line="125"/>
         <source>Reverse</source>
         <translation>逆</translation>
     </message>
     <message>
-        <location filename="gui/opt/KeyOptionWidget.cpp" line="131"/>
+        <location filename="gui/opt/KeyOptionWidget.cpp" line="130"/>
         <source>Auto Titles</source>
         <translation>自動タイトル</translation>
     </message>
     <message>
-        <location filename="gui/opt/KeyOptionWidget.cpp" line="136"/>
+        <location filename="gui/opt/KeyOptionWidget.cpp" line="135"/>
         <source>Enhanced</source>
         <translation>強化</translation>
     </message>
     <message>
-        <location filename="gui/opt/KeyOptionWidget.cpp" line="141"/>
+        <location filename="gui/opt/KeyOptionWidget.cpp" line="140"/>
         <source>Sample Length:</source>
         <translation>サンプルの長さ:</translation>
     </message>
     <message>
-        <location filename="gui/opt/KeyOptionWidget.cpp" line="148"/>
+        <location filename="gui/opt/KeyOptionWidget.cpp" line="147"/>
         <source>Spacing:</source>
         <translation>スペース:</translation>
     </message>
     <message>
-        <location filename="gui/opt/KeyOptionWidget.cpp" line="155"/>
+        <location filename="gui/opt/KeyOptionWidget.cpp" line="154"/>
         <source>Width Increment:</source>
         <translation>幅の増分:</translation>
     </message>
     <message>
-        <location filename="gui/opt/KeyOptionWidget.cpp" line="163"/>
+        <location filename="gui/opt/KeyOptionWidget.cpp" line="162"/>
         <source>Height Increment:</source>
         <translation>高さの増分:</translation>
     </message>
     <message>
-        <location filename="gui/opt/KeyOptionWidget.cpp" line="171"/>
+        <location filename="gui/opt/KeyOptionWidget.cpp" line="170"/>
         <source>Legend Title:</source>
         <translation>凡例のタイトル:</translation>
     </message>
     <message>
-        <location filename="gui/opt/KeyOptionWidget.cpp" line="40"/>
+        <location filename="gui/opt/KeyOptionWidget.cpp" line="41"/>
         <source>Legend</source>
         <translation>凡例</translation>
     </message>
     <message>
-        <location filename="gui/opt/KeyOptionWidget.cpp" line="58"/>
+        <location filename="gui/opt/KeyOptionWidget.cpp" line="59"/>
         <source>Ac&amp;tivation</source>
         <translation>有効化(&amp;T)</translation>
     </message>
     <message>
-        <location filename="gui/opt/KeyOptionWidget.cpp" line="257"/>
+        <location filename="gui/opt/KeyOptionWidget.cpp" line="256"/>
         <source>&amp;Position</source>
         <translation>位置(&amp;P)</translation>
     </message>
     <message>
-        <location filename="gui/opt/KeyOptionWidget.cpp" line="182"/>
+        <location filename="gui/opt/KeyOptionWidget.cpp" line="181"/>
         <source>&amp;Line Type:</source>
         <translation>線の種類(&amp;L):</translation>
     </message>
     <message>
-        <location filename="gui/opt/KeyOptionWidget.cpp" line="190"/>
+        <location filename="gui/opt/KeyOptionWidget.cpp" line="189"/>
         <source>L&amp;ine Width:</source>
         <translation>線の幅(&amp;I):</translation>
     </message>
     <message>
-        <location filename="gui/opt/KeyOptionWidget.cpp" line="209"/>
+        <location filename="gui/opt/KeyOptionWidget.cpp" line="208"/>
         <source>Bo&amp;x</source>
         <translation>ボックス(&amp;X)</translation>
     </message>
     <message>
-        <location filename="gui/opt/KeyOptionWidget.cpp" line="259"/>
+        <location filename="gui/opt/KeyOptionWidget.cpp" line="258"/>
         <source>Ot&amp;hers</source>
         <translation>その他(&amp;H)</translation>
     </message>
     <message>
-        <location filename="gui/opt/KeyOptionWidget.cpp" line="113"/>
+        <location filename="gui/opt/KeyOptionWidget.cpp" line="112"/>
         <source>Corner</source>
         <translation>角</translation>
     </message>
     <message>
-        <location filename="gui/opt/KeyOptionWidget.cpp" line="114"/>
+        <location filename="gui/opt/KeyOptionWidget.cpp" line="113"/>
         <source>Coordinate</source>
         <translation>座標</translation>
     </message>
     <message>
-        <location filename="gui/opt/KeyOptionWidget.cpp" line="258"/>
+        <location filename="gui/opt/KeyOptionWidget.cpp" line="257"/>
         <source>&amp;Box and Title</source>
         <translation>ボックスとタイトル(&amp;B)</translation>
     </message>
@@ -678,224 +730,250 @@
         <translation>削除(&amp;E)</translation>
     </message>
     <message>
-        <location filename="gui/MainWindow.cpp" line="542"/>
+        <location filename="gui/MainWindow.cpp" line="553"/>
         <source>&amp;Quit</source>
         <translation>終了(&amp;Q)</translation>
     </message>
     <message>
-        <location filename="gui/MainWindow.cpp" line="181"/>
+        <location filename="gui/MainWindow.cpp" line="185"/>
         <source>&amp;2D Plot</source>
         <translation>&amp;2D プロット</translation>
     </message>
     <message>
-        <location filename="gui/MainWindow.cpp" line="188"/>
+        <location filename="gui/MainWindow.cpp" line="192"/>
         <source>&amp;3D Plot</source>
         <translation>&amp;3D プロット</translation>
     </message>
     <message>
-        <location filename="gui/MainWindow.cpp" line="229"/>
+        <location filename="gui/MainWindow.cpp" line="233"/>
         <source>&amp;About</source>
         <translation>Cueplot について(&amp;A)</translation>
     </message>
     <message>
-        <location filename="gui/MainWindow.cpp" line="243"/>
+        <location filename="gui/MainWindow.cpp" line="247"/>
         <source>&amp;File</source>
         <translation>ファイル(&amp;F)</translation>
     </message>
     <message>
-        <location filename="gui/MainWindow.cpp" line="250"/>
+        <location filename="gui/MainWindow.cpp" line="254"/>
         <source>&amp;Command</source>
         <translation>コマンド(&amp;C)</translation>
     </message>
     <message>
-        <location filename="gui/MainWindow.cpp" line="263"/>
+        <location filename="gui/MainWindow.cpp" line="267"/>
         <source>&amp;Help</source>
         <translation>ヘルプ(&amp;H)</translation>
     </message>
     <message>
-        <location filename="gui/MainWindow.cpp" line="236"/>
+        <location filename="gui/MainWindow.cpp" line="240"/>
         <source>About &amp;Qt</source>
         <translation>&amp;Qt について</translation>
     </message>
     <message>
-        <location filename="gui/MainWindow.cpp" line="150"/>
+        <location filename="gui/MainWindow.cpp" line="151"/>
         <source>&amp;Open...</source>
         <translation>開く(&amp;O)...</translation>
     </message>
     <message>
-        <location filename="gui/MainWindow.cpp" line="164"/>
+        <location filename="gui/MainWindow.cpp" line="165"/>
         <source>Save &amp;As...</source>
         <translation>名前を付けて保存(&amp;A)...</translation>
     </message>
     <message>
-        <location filename="gui/MainWindow.cpp" line="195"/>
+        <location filename="gui/MainWindow.cpp" line="199"/>
         <source>&amp;Raw Commands...</source>
         <translation>生のコマンド(&amp;R)...</translation>
     </message>
     <message>
-        <location filename="gui/MainWindow.cpp" line="200"/>
+        <location filename="gui/MainWindow.cpp" line="204"/>
         <source>&amp;Fittings...</source>
         <translation>フィッティング(&amp;F)...</translation>
     </message>
     <message>
-        <location filename="gui/MainWindow.cpp" line="205"/>
+        <location filename="gui/MainWindow.cpp" line="209"/>
         <source>&amp;Settings...</source>
         <translation>設定(&amp;S)...</translation>
     </message>
     <message>
-        <location filename="gui/MainWindow.cpp" line="157"/>
+        <location filename="gui/MainWindow.cpp" line="158"/>
         <source>&amp;Save</source>
         <translation>保存(&amp;S)</translation>
     </message>
     <message>
-        <location filename="gui/MainWindow.cpp" line="401"/>
+        <location filename="gui/MainWindow.cpp" line="408"/>
         <source>Save under a file name</source>
         <translation>名前を付けて保存する</translation>
     </message>
     <message>
-        <location filename="gui/MainWindow.cpp" line="414"/>
+        <location filename="gui/MainWindow.cpp" line="420"/>
         <source>Open a file</source>
         <translation>ファイルを開く</translation>
     </message>
     <message>
-        <location filename="gui/MainWindow.cpp" line="379"/>
+        <location filename="gui/MainWindow.cpp" line="387"/>
         <source>Open a data file</source>
         <translation>データファイルを開く</translation>
     </message>
     <message>
-        <location filename="gui/MainWindow.cpp" line="504"/>
+        <location filename="gui/MainWindow.cpp" line="514"/>
         <source>About %1</source>
         <translation>%1 について</translation>
     </message>
     <message>
-        <location filename="gui/MainWindow.cpp" line="182"/>
+        <location filename="gui/MainWindow.cpp" line="186"/>
         <source>F2</source>
         <translation>F2</translation>
     </message>
     <message>
-        <location filename="gui/MainWindow.cpp" line="189"/>
+        <location filename="gui/MainWindow.cpp" line="193"/>
         <source>F3</source>
         <translation>F3</translation>
     </message>
     <message>
-        <location filename="gui/MainWindow.cpp" line="151"/>
+        <location filename="gui/MainWindow.cpp" line="152"/>
         <source>Ctrl+O</source>
         <translation>Ctrl+O</translation>
     </message>
     <message>
-        <location filename="gui/MainWindow.cpp" line="269"/>
+        <location filename="gui/MainWindow.cpp" line="273"/>
         <source>Tool Bar</source>
         <translation>ツールバー</translation>
     </message>
     <message>
-        <location filename="gui/MainWindow.cpp" line="217"/>
+        <location filename="gui/MainWindow.cpp" line="221"/>
         <source>&amp;Console...</source>
         <translation>コンソール(&amp;C)...</translation>
     </message>
     <message>
-        <location filename="gui/MainWindow.cpp" line="257"/>
+        <location filename="gui/MainWindow.cpp" line="261"/>
         <source>&amp;Settings</source>
         <translation>設定(&amp;S)</translation>
     </message>
     <message>
-        <location filename="gui/MainWindow.cpp" line="214"/>
+        <location filename="gui/MainWindow.cpp" line="218"/>
         <source>&amp;Tool Bar</source>
         <translation>ツールバー(&amp;T)</translation>
     </message>
     <message>
-        <location filename="gui/MainWindow.cpp" line="538"/>
+        <location filename="gui/MainWindow.cpp" line="549"/>
         <source>Confirmation</source>
         <translation>確認</translation>
     </message>
     <message>
-        <location filename="gui/MainWindow.cpp" line="541"/>
+        <location filename="gui/MainWindow.cpp" line="552"/>
         <source>Function(s) and/or data exist in the list.
 Are you sure you want to quit?</source>
         <translation>関数やデータがリスト中にあります。
 本当に終了しますか?</translation>
     </message>
     <message>
-        <location filename="gui/MainWindow.cpp" line="542"/>
+        <location filename="gui/MainWindow.cpp" line="553"/>
         <source>&amp;Cancel</source>
         <translation>キャンセル(&amp;C)</translation>
     </message>
     <message>
-        <location filename="gui/MainWindow.cpp" line="152"/>
+        <location filename="gui/MainWindow.cpp" line="153"/>
         <source>load &quot;&amp;lt;input-file&amp;gt;&quot;</source>
         <translation>load &quot;&amp;lt;入力ファイル&amp;gt;&quot;</translation>
     </message>
     <message>
-        <location filename="gui/MainWindow.cpp" line="165"/>
+        <location filename="gui/MainWindow.cpp" line="166"/>
         <source>save &apos;&amp;lt;filename&amp;gt;&apos;</source>
         <translation>save &apos;&amp;lt;ファイル名&amp;gt;&apos;</translation>
     </message>
     <message>
-        <location filename="gui/MainWindow.cpp" line="223"/>
+        <location filename="gui/MainWindow.cpp" line="227"/>
         <source>What&apos;s &amp;This?</source>
         <translation>これは何?(&amp;T)</translation>
     </message>
     <message>
-        <location filename="gui/MainWindow.cpp" line="224"/>
+        <location filename="gui/MainWindow.cpp" line="228"/>
         <source>Shift+F1</source>
         <translation>Shift+F1</translation>
     </message>
     <message>
-        <location filename="gui/MainWindow.cpp" line="158"/>
+        <location filename="gui/MainWindow.cpp" line="159"/>
         <source>Ctrl+S</source>
         <translation>Ctrl+S</translation>
     </message>
     <message>
-        <location filename="gui/MainWindow.cpp" line="171"/>
+        <location filename="gui/MainWindow.cpp" line="172"/>
         <source>Ctrl+Q</source>
         <translation>Ctrl+Q</translation>
     </message>
     <message>
-        <location filename="gui/MainWindow.cpp" line="519"/>
-        <source>: a GUI front end to gnuplot&lt;br&gt;Copyright (C) 2007 Muneyuki Noguchi&lt;/p&gt;&lt;p&gt;This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.&lt;/p&gt;&lt;p&gt;This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.&lt;/p&gt;&lt;p&gt;You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.&lt;/p&gt;</source>
+        <location filename="gui/MainWindow.cpp" line="529"/>
+        <source>: a GUI front-end to gnuplot&lt;br&gt;Copyright (C) 2007 Muneyuki Noguchi&lt;/p&gt;&lt;p&gt;This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.&lt;/p&gt;&lt;p&gt;This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.&lt;/p&gt;&lt;p&gt;You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.&lt;/p&gt;</source>
         <translation>: gnuplot の GUI フロントエンド&lt;br&gt;Copyright (C) 2007 Muneyuki Noguchi&lt;/p&gt;&lt;p&gt;このプログラムはフリーソフトウェアです。あなたはこれを、フリーソフトウェア財団によって発行された GNU 一般公衆利用許諾契約書（バージョン2か、希望によってはそれ以降のバージョンのうちどれか）の定める条件の下で再頒布または改変することができます。&lt;/p&gt;&lt;p&gt;このプログラムは有用であることを願って頒布されますが、*全くの無保証* です。商業可能性の保証や特定の目的への適合性は、言外に示されたものも含め全く存在しません。詳しくはGNU 一般公衆利用許諾契約書をご覧ください。&lt;/p&gt;&lt;p&gt;あなたはこのプログラムと共に、GNU 一般公衆利用許諾契約書の複製物を一部受け取ったはずです。もし受け取っていなければ、フリーソフトウェア財団まで請求してください（宛先は the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA）。&lt;/p&gt;</translation>
     </message>
 </context>
+<context>
+    <name>Mapping</name>
+    <message>
+        <location filename="opt/Mapping.cpp" line="22"/>
+        <source>cartesian</source>
+        <translation>直交</translation>
+    </message>
+    <message>
+        <location filename="opt/Mapping.cpp" line="23"/>
+        <source>spherical</source>
+        <translation>極</translation>
+    </message>
+    <message>
+        <location filename="opt/Mapping.cpp" line="24"/>
+        <source>cylindrical</source>
+        <translation>円筒</translation>
+    </message>
+</context>
+<context>
+    <name>MappingOptionWidget</name>
+    <message>
+        <location filename="gui/opt/MappingOptionWidget.cpp" line="29"/>
+        <source>Coordinate</source>
+        <translation>座標</translation>
+    </message>
+</context>
 <context>
     <name>OptionDialog</name>
     <message>
-        <location filename="gui/OptionDialog.cpp" line="113"/>
+        <location filename="gui/OptionDialog.cpp" line="123"/>
         <source>&amp;Default</source>
         <translation>標準設定(&amp;D)</translation>
     </message>
     <message>
-        <location filename="gui/OptionDialog.cpp" line="120"/>
+        <location filename="gui/OptionDialog.cpp" line="130"/>
         <source>&amp;OK</source>
         <translation>&amp;OK</translation>
     </message>
     <message>
-        <location filename="gui/OptionDialog.cpp" line="211"/>
+        <location filename="gui/OptionDialog.cpp" line="223"/>
         <source>&amp;Apply</source>
         <translation>適用(&amp;A)</translation>
     </message>
     <message>
-        <location filename="gui/OptionDialog.cpp" line="211"/>
+        <location filename="gui/OptionDialog.cpp" line="223"/>
         <source>&amp;Cancel</source>
         <translation>キャンセル(&amp;C)</translation>
     </message>
     <message>
-        <location filename="gui/OptionDialog.cpp" line="70"/>
+        <location filename="gui/OptionDialog.cpp" line="75"/>
         <source>Settings</source>
         <translation>設定</translation>
     </message>
     <message>
-        <location filename="gui/OptionDialog.cpp" line="206"/>
+        <location filename="gui/OptionDialog.cpp" line="218"/>
         <source>Unsaved Changes</source>
         <translation>未保存の変更</translation>
     </message>
     <message>
-        <location filename="gui/OptionDialog.cpp" line="210"/>
+        <location filename="gui/OptionDialog.cpp" line="222"/>
         <source>There are unsaved changes in this option.
 Do you want to apply the changes before opening the new option?</source>
         <translation>このオプションには未保存の変更があります。
 新しいオプションを開く前に変更を適用しますか?</translation>
     </message>
     <message>
-        <location filename="gui/OptionDialog.cpp" line="211"/>
+        <location filename="gui/OptionDialog.cpp" line="223"/>
         <source>&amp;Discard</source>
         <translation>破棄(&amp;D)</translation>
     </message>
@@ -923,6 +1001,19 @@ Do you want to apply the changes before opening the new option?</source>
         <translation>出力を設定</translation>
     </message>
 </context>
+<context>
+    <name>ParametricOptionWidget</name>
+    <message>
+        <location filename="gui/opt/ParametricOptionWidget.cpp" line="28"/>
+        <source>Parameter</source>
+        <translation>媒介変数</translation>
+    </message>
+    <message>
+        <location filename="gui/opt/ParametricOptionWidget.cpp" line="40"/>
+        <source>Parametric Functions</source>
+        <translation>媒介変数表示</translation>
+    </message>
+</context>
 <context>
     <name>PlotModifierWidget</name>
     <message>
@@ -1039,42 +1130,42 @@ Do you want to apply the changes before opening the new option?</source>
 <context>
     <name>PlotOptionDialog</name>
     <message>
-        <location filename="gui/PlotOptionDialog.cpp" line="82"/>
+        <location filename="gui/PlotOptionDialog.cpp" line="83"/>
         <source>&amp;Apply</source>
         <translation>適用(&amp;A)</translation>
     </message>
     <message>
-        <location filename="gui/PlotOptionDialog.cpp" line="86"/>
+        <location filename="gui/PlotOptionDialog.cpp" line="87"/>
         <source>&amp;Cancel</source>
         <translation>キャンセル(&amp;C)</translation>
     </message>
     <message>
-        <location filename="gui/PlotOptionDialog.cpp" line="76"/>
+        <location filename="gui/PlotOptionDialog.cpp" line="77"/>
         <source>&amp;OK</source>
         <translation>&amp;OK</translation>
     </message>
     <message>
-        <location filename="gui/PlotOptionDialog.cpp" line="112"/>
+        <location filename="gui/PlotOptionDialog.cpp" line="113"/>
         <source>Options of %1 %2</source>
         <translation>%1 %2 のオプション</translation>
     </message>
     <message>
-        <location filename="gui/PlotOptionDialog.cpp" line="112"/>
+        <location filename="gui/PlotOptionDialog.cpp" line="113"/>
         <source>Function</source>
         <translation>関数</translation>
     </message>
     <message>
-        <location filename="gui/PlotOptionDialog.cpp" line="112"/>
+        <location filename="gui/PlotOptionDialog.cpp" line="113"/>
         <source>Data File</source>
         <translation>データファイル</translation>
     </message>
     <message>
-        <location filename="gui/PlotOptionDialog.cpp" line="64"/>
+        <location filename="gui/PlotOptionDialog.cpp" line="65"/>
         <source>&amp;2D Plot Test</source>
         <translation>&amp;2D プロットテスト</translation>
     </message>
     <message>
-        <location filename="gui/PlotOptionDialog.cpp" line="72"/>
+        <location filename="gui/PlotOptionDialog.cpp" line="73"/>
         <source>&amp;3D Plot Test</source>
         <translation>&amp;3D プロットテスト</translation>
     </message>
@@ -1166,40 +1257,47 @@ Do you want to apply the changes before opening the new option?</source>
 <context>
     <name>Process</name>
     <message>
-        <location filename="gui/Process.cpp" line="35"/>
-        <source>Application will now exit</source>
-        <translation>アプリケーションは今、終了します</translation>
-    </message>
-    <message>
-        <location filename="gui/Process.cpp" line="35"/>
-        <source>Could not start gnuplot
-</source>
-        <translation>gnuplot を起動できませんでした</translation>
-    </message>
-    <message>
-        <location filename="gui/Process.cpp" line="70"/>
+        <location filename="gui/Process.cpp" line="73"/>
         <source>Open gnuplot</source>
         <translation>gnuplot を開く</translation>
     </message>
+    <message>
+        <location filename="gui/Process.cpp" line="34"/>
+        <source>Gnuplot could not be started</source>
+        <translation>Gnuplot を起動できませんでした</translation>
+    </message>
 </context>
 <context>
     <name>RawCommandDialog</name>
     <message>
-        <location filename="gui/RawCommandDialog.cpp" line="49"/>
+        <location filename="gui/RawCommandDialog.cpp" line="48"/>
         <source>Raw Commands</source>
         <translation>生のコマンド</translation>
     </message>
     <message>
-        <location filename="gui/RawCommandDialog.cpp" line="56"/>
+        <location filename="gui/RawCommandDialog.cpp" line="55"/>
         <source>&amp;Execute</source>
         <translation>実行(&amp;E)</translation>
     </message>
     <message>
-        <location filename="gui/RawCommandDialog.cpp" line="64"/>
+        <location filename="gui/RawCommandDialog.cpp" line="63"/>
         <source>&amp;Close</source>
         <translation>閉じる(&amp;C)</translation>
     </message>
 </context>
+<context>
+    <name>SamplesOptionWidget</name>
+    <message>
+        <location filename="gui/opt/SamplesOptionWidget.cpp" line="29"/>
+        <source>Sampling</source>
+        <translation>サンプリング</translation>
+    </message>
+    <message>
+        <location filename="gui/opt/SamplesOptionWidget.cpp" line="55"/>
+        <source>Samples</source>
+        <translation>サンプル</translation>
+    </message>
+</context>
 <context>
     <name>SizeOptionWidget</name>
     <message>
@@ -1223,15 +1321,23 @@ Do you want to apply the changes before opening the new option?</source>
         <translation>垂直サイズ(&amp;V):</translation>
     </message>
 </context>
+<context>
+    <name>TerminalLatexEmtex</name>
+    <message>
+        <location filename="opt/terminal/TerminalLatexEmtex.cpp" line="23"/>
+        <source>default</source>
+        <translation>標準設定</translation>
+    </message>
+</context>
 <context>
     <name>TerminalLatexEmtexOptionWidget</name>
     <message>
-        <location filename="gui/opt/terminal/TerminalLatexEmtexOptionWidget.cpp" line="47"/>
+        <location filename="gui/opt/terminal/TerminalLatexEmtexOptionWidget.cpp" line="49"/>
         <source>&amp;Font:</source>
         <translation>フォント(&amp;F):</translation>
     </message>
     <message>
-        <location filename="gui/opt/terminal/TerminalLatexEmtexOptionWidget.cpp" line="55"/>
+        <location filename="gui/opt/terminal/TerminalLatexEmtexOptionWidget.cpp" line="57"/>
         <source>&amp;Size:</source>
         <translation>サイズ(&amp;S):</translation>
     </message>
@@ -1255,107 +1361,113 @@ Do you want to apply the changes before opening the new option?</source>
     </message>
 </context>
 <context>
-    <name>TerminalPbmOptionWidget</name>
+    <name>TerminalPbm</name>
     <message>
-        <location filename="gui/opt/terminal/TerminalPbmOptionWidget.cpp" line="39"/>
+        <location filename="opt/terminal/TerminalPbm.cpp" line="22"/>
         <source>small</source>
         <translation>小</translation>
     </message>
     <message>
-        <location filename="gui/opt/terminal/TerminalPbmOptionWidget.cpp" line="40"/>
+        <location filename="opt/terminal/TerminalPbm.cpp" line="23"/>
         <source>medium</source>
         <translation>中</translation>
     </message>
     <message>
-        <location filename="gui/opt/terminal/TerminalPbmOptionWidget.cpp" line="41"/>
+        <location filename="opt/terminal/TerminalPbm.cpp" line="24"/>
         <source>large</source>
         <translation>大</translation>
     </message>
     <message>
-        <location filename="gui/opt/terminal/TerminalPbmOptionWidget.cpp" line="46"/>
-        <source>&amp;Font Size:</source>
-        <translation>フォントのサイズ(&amp;F):</translation>
-    </message>
-    <message>
-        <location filename="gui/opt/terminal/TerminalPbmOptionWidget.cpp" line="50"/>
+        <location filename="opt/terminal/TerminalPbm.cpp" line="29"/>
         <source>monochrome</source>
         <translation>モノクロ</translation>
     </message>
     <message>
-        <location filename="gui/opt/terminal/TerminalPbmOptionWidget.cpp" line="51"/>
+        <location filename="opt/terminal/TerminalPbm.cpp" line="30"/>
         <source>gray</source>
         <translation>グレー</translation>
     </message>
     <message>
-        <location filename="gui/opt/terminal/TerminalPbmOptionWidget.cpp" line="52"/>
+        <location filename="opt/terminal/TerminalPbm.cpp" line="31"/>
         <source>color</source>
         <translation>カラー</translation>
     </message>
+</context>
+<context>
+    <name>TerminalPbmOptionWidget</name>
     <message>
-        <location filename="gui/opt/terminal/TerminalPbmOptionWidget.cpp" line="57"/>
+        <location filename="gui/opt/terminal/TerminalPbmOptionWidget.cpp" line="48"/>
+        <source>&amp;Font Size:</source>
+        <translation>フォントのサイズ(&amp;F):</translation>
+    </message>
+    <message>
+        <location filename="gui/opt/terminal/TerminalPbmOptionWidget.cpp" line="60"/>
         <source>Co&amp;lormode:</source>
         <translation>色モード(&amp;L):</translation>
     </message>
 </context>
 <context>
-    <name>TerminalPostScriptOptionWidget</name>
+    <name>TerminalPostScript</name>
     <message>
-        <location filename="gui/opt/terminal/TerminalPostScriptOptionWidget.cpp" line="42"/>
+        <location filename="opt/terminal/TerminalPostScript.cpp" line="22"/>
         <source>landscape</source>
         <translation>横方向</translation>
     </message>
     <message>
-        <location filename="gui/opt/terminal/TerminalPostScriptOptionWidget.cpp" line="43"/>
+        <location filename="opt/terminal/TerminalPostScript.cpp" line="23"/>
         <source>portrait</source>
         <translation>縦方向</translation>
     </message>
     <message>
-        <location filename="gui/opt/terminal/TerminalPostScriptOptionWidget.cpp" line="49"/>
-        <source>&amp;Mode:</source>
-        <translation>モード(&amp;M):</translation>
-    </message>
-    <message>
-        <location filename="gui/opt/terminal/TerminalPostScriptOptionWidget.cpp" line="53"/>
+        <location filename="opt/terminal/TerminalPostScript.cpp" line="29"/>
         <source>color</source>
         <translation>カラー</translation>
     </message>
     <message>
-        <location filename="gui/opt/terminal/TerminalPostScriptOptionWidget.cpp" line="54"/>
+        <location filename="opt/terminal/TerminalPostScript.cpp" line="30"/>
         <source>monochrome</source>
         <translation>モノクロ</translation>
     </message>
     <message>
-        <location filename="gui/opt/terminal/TerminalPostScriptOptionWidget.cpp" line="59"/>
-        <source>Co&amp;lor:</source>
-        <translation>色(&amp;L):</translation>
-    </message>
-    <message>
-        <location filename="gui/opt/terminal/TerminalPostScriptOptionWidget.cpp" line="63"/>
+        <location filename="opt/terminal/TerminalPostScript.cpp" line="35"/>
         <source>solid</source>
         <translation>実線</translation>
     </message>
     <message>
-        <location filename="gui/opt/terminal/TerminalPostScriptOptionWidget.cpp" line="64"/>
+        <location filename="opt/terminal/TerminalPostScript.cpp" line="36"/>
         <source>dashed</source>
         <translation>破線</translation>
     </message>
+</context>
+<context>
+    <name>TerminalPostScriptOptionWidget</name>
     <message>
-        <location filename="gui/opt/terminal/TerminalPostScriptOptionWidget.cpp" line="69"/>
+        <location filename="gui/opt/terminal/TerminalPostScriptOptionWidget.cpp" line="51"/>
+        <source>&amp;Mode:</source>
+        <translation>モード(&amp;M):</translation>
+    </message>
+    <message>
+        <location filename="gui/opt/terminal/TerminalPostScriptOptionWidget.cpp" line="63"/>
+        <source>Co&amp;lor:</source>
+        <translation>色(&amp;L):</translation>
+    </message>
+    <message>
+        <location filename="gui/opt/terminal/TerminalPostScriptOptionWidget.cpp" line="75"/>
         <source>Da&amp;shed:</source>
         <translation>破線(&amp;S):</translation>
     </message>
     <message>
-        <location filename="gui/opt/terminal/TerminalPostScriptOptionWidget.cpp" line="77"/>
+        <location filename="gui/opt/terminal/TerminalPostScriptOptionWidget.cpp" line="83"/>
         <source>&amp;Font Name:</source>
         <translation>フォントの名前(&amp;F):</translation>
     </message>
     <message>
-        <location filename="gui/opt/terminal/TerminalPostScriptOptionWidget.cpp" line="85"/>
+        <location filename="gui/opt/terminal/TerminalPostScriptOptionWidget.cpp" line="91"/>
         <source>Fo&amp;nt Size:</source>
         <translation>フォントのサイズ(&amp;N):</translation>
     </message>
     <message>
-        <location filename="gui/opt/terminal/TerminalPostScriptOptionWidget.cpp" line="89"/>
+        <location filename="gui/opt/terminal/TerminalPostScriptOptionWidget.cpp" line="95"/>
         <source>&amp;Enhanced</source>
         <translation>強化(&amp;E)</translation>
     </message>
@@ -1388,4 +1500,37 @@ Do you want to apply the changes before opening the new option?</source>
         <translation>フォントの名前(&amp;F):</translation>
     </message>
 </context>
+<context>
+    <name>ViewOptionWidget</name>
+    <message>
+        <location filename="gui/opt/ViewOptionWidget.cpp" line="30"/>
+        <source>View</source>
+        <translation>視点</translation>
+    </message>
+    <message>
+        <location filename="gui/opt/ViewOptionWidget.cpp" line="42"/>
+        <source>&amp;Map</source>
+        <translation>地図(&amp;M)</translation>
+    </message>
+    <message>
+        <location filename="gui/opt/ViewOptionWidget.cpp" line="54"/>
+        <source>&amp;X Axis</source>
+        <translation>&amp;X 軸</translation>
+    </message>
+    <message>
+        <location filename="gui/opt/ViewOptionWidget.cpp" line="67"/>
+        <source>&amp;Z Axis</source>
+        <translation>&amp;Z 軸</translation>
+    </message>
+    <message>
+        <location filename="gui/opt/ViewOptionWidget.cpp" line="79"/>
+        <source>&amp;Scale</source>
+        <translation>縮尺(&amp;S)</translation>
+    </message>
+    <message>
+        <location filename="gui/opt/ViewOptionWidget.cpp" line="91"/>
+        <source>Sca&amp;le of Z Axis</source>
+        <translation>Z 軸の縮尺(&amp;L)</translation>
+    </message>
+</context>
 </TS>
