@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -18,10 +18,10 @@
  */
 #include "ConsoleDialog.h"
 
-#include <QApplication>
-#include <QCoreApplication>
-#include <QTextEdit>
-#include <QVBoxLayout>
+#include <QtCore/QCoreApplication>
+#include <QtGui/QApplication>
+#include <QtGui/QTextEdit>
+#include <QtGui/QVBoxLayout>
 
 ConsoleDialog::ConsoleDialog(QWidget *parent)
 : QDialog(parent)
@@ -39,6 +39,7 @@ ConsoleDialog::ConsoleDialog(QWidget *parent)
 }
 
 namespace {
+	//! '&lt;' などをエスケープし、改行を &lt;br&gt; に置き換える
 	QString escape(const QString &str)
 	{
 		QString escapedStr = str;
@@ -63,6 +64,7 @@ void ConsoleDialog::readStandardError(const QByteArray &output)
 	QString command = QString(output.data());
 	if (!command.trimmed().isEmpty()) {
 		command = escape(command);
+		// エラー出力は赤で表示
 		consoleTextEdit->append("<kbd><font color=\"red\">" +
 				command + "</font></kbd>");
 	}
