@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -19,17 +19,20 @@
 #ifndef CONSOLE_DIALOG_INCLUDED
 #define CONSOLE_DIALOG_INCLUDED
 
-#include <QDialog>
+#include <QtGui/QDialog>
 class QTextEdit;
 
+//! 実行されたコマンドや出力されたエラーメッセージを表示するダイアログ
 class ConsoleDialog : public QDialog
 {
 	Q_OBJECT
 
 	public:
-		ConsoleDialog(QWidget *parent = 0);
+		explicit ConsoleDialog(QWidget *parent = 0);
 
+		//! 実行されたコマンドを表示する
 		void execute(const QString &command);
+		//! 出力されたエラーメッセージを表示する
 		void readStandardError(const QByteArray &output);
 
 	private:
