@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -23,12 +23,12 @@
 #include "FitRangeWidget.h"
 #include "Fit.h"
 
-#include <QCoreApplication>
-#include <QListWidget>
-#include <QHBoxLayout>
-#include <QPushButton>
-#include <QSplitter>
-#include <QStackedWidget>
+#include <QtCore/QCoreApplication>
+#include <QtGui/QListWidget>
+#include <QtGui/QHBoxLayout>
+#include <QtGui/QPushButton>
+#include <QtGui/QSplitter>
+#include <QtGui/QStackedWidget>
 
 FitDialog *FitDialog::instance_ = 0;
 
@@ -109,7 +109,6 @@ FitDialog::FitDialog(QWidget *parent)
 void FitDialog::init()
 {
 	Fit fit;
-	// insert current options
 	fitBasicWidget->setFitFunction(fit.function());
 	fitBasicWidget->setFitDataFile(fit.dataFile());
 	fitBasicWidget->setFitParameterFile(fit.isParameterFile());
@@ -126,7 +125,6 @@ void FitDialog::init()
 
 void FitDialog::fit()
 {
-	// get current options
 	Fit fit;
 
 	fit.setFunction(fitBasicWidget->fitFunction());
