@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -24,19 +24,19 @@
 #include "Process.h"
 #include "RawCommandDialog.h"
 
-#include <QCloseEvent>
-#include <QCoreApplication>
-#include <QLineEdit>
-#include <QListWidget>
-#include <QFileDialog>
-#include <QMenu>
-#include <QMenuBar>
-#include <QMessageBox>
-#include <QPushButton>
-#include <QRadioButton>
-#include <QToolBar>
-#include <QVBoxLayout>
-#include <QWhatsThis>
+#include <QtCore/QCoreApplication>
+#include <QtGui/QCloseEvent>
+#include <QtGui/QLineEdit>
+#include <QtGui/QListWidget>
+#include <QtGui/QFileDialog>
+#include <QtGui/QMenu>
+#include <QtGui/QMenuBar>
+#include <QtGui/QMessageBox>
+#include <QtGui/QPushButton>
+#include <QtGui/QRadioButton>
+#include <QtGui/QToolBar>
+#include <QtGui/QVBoxLayout>
+#include <QtGui/QWhatsThis>
 
 MainWindow::MainWindow(QWidget *parent)
 : QMainWindow(parent), process(new Process)
@@ -132,6 +132,7 @@ MainWindow::MainWindow(QWidget *parent)
 	listLayout->addWidget(optionPushButton, 1, 0);
 	listLayout->addWidget(upPushButton, 2, 0);
 	listLayout->addWidget(downPushButton, 3, 0);
+	// ウィンドウを最大化したときのことを考えて、QSpacerItem を入れる
 	listLayout->addItem(new QSpacerItem(20, 0, 
 				QSizePolicy::Minimum, QSizePolicy::Expanding), 4, 0);
 	listLayout->addItem(new QSpacerItem(40, 20, 
@@ -147,31 +148,41 @@ MainWindow::MainWindow(QWidget *parent)
 	mainWidget->setLayout(mainLayout);
 	setCentralWidget(mainWidget);
 
-	QAction *loadAct = new QAction(tr("&Open..."), this);
+	createActions();
+	createMenus();
+	createToolBars();
+}
+
+void MainWindow::createActions()
+{
+	loadAct = new QAction(tr("&Open..."), this);
 	loadAct->setShortcut(tr("Ctrl+O"));
 	loadAct->setWhatsThis(tr("load \"&lt;input-file&gt;\""));
 	loadAct->setIcon(QIcon(":/images/fileopen.png"));
 	connect(loadAct, SIGNAL(triggered()),
 			this, SLOT(load()));
 
-	QAction *saveAct = new QAction(tr("&Save"), this);
+	saveAct = new QAction(tr("&Save"), this);
 	saveAct->setShortcut(tr("Ctrl+S"));
 	saveAct->setWhatsThis(tr("save '&lt;filename&gt;'"));
 	saveAct->setIcon(QIcon(":/images/filesave.png"));
 	connect(saveAct, SIGNAL(triggered()),
 			this, SLOT(save()));
 
-	QAction *saveAsAct = new QAction(tr("Save &As..."), this);
+	saveAsAct = new QAction(tr("Save &As..."), this);
 	saveAsAct->setWhatsThis(tr("save '&lt;filename&gt;'"));
 	saveAsAct->setIcon(QIcon(":/images/filesaveas.png"));
 	connect(saveAsAct, SIGNAL(triggered()),
 			this, SLOT(saveAs()));
 
-	QAction *quitAct = new QAction(tr("&Quit"), this);
+	quitAct = new QAction(tr("&Quit"), this);
 	quitAct->setShortcut(tr("Ctrl+Q"));
 	quitAct->setWhatsThis("quit");
 	quitAct->setIcon(QIcon(":/images/exit.png"));
-#if QT_VERSION >= 0x040200
+#if QT_VERSION >= 0x040200 && defined(Q_OS_DARWIN)
+	// Mac OS X 環境で、使用している言語によりメニューの場所が変わるのを
+	// 防ぐための処理
+	// setMenuRole() は Qt 4.2 で導入された
 	quitAct->setMenuRole(QAction::QuitRole);
 #endif
 	connect(quitAct, SIGNAL(triggered()),
@@ -192,19 +203,19 @@ MainWindow::MainWindow(QWidget *parent)
 	connect(splotAct, SIGNAL(triggered()),
 			this, SLOT(splot()));
 
-	QAction *rawCommandAct = new QAction(tr("&Raw Commands..."), this);
+	rawCommandAct = new QAction(tr("&Raw Commands..."), this);
 	rawCommandAct->setIcon(QIcon(":/images/run.png"));
 	connect(rawCommandAct, SIGNAL(triggered()),
 			this, SLOT(rawCommand()));
 
-	QAction *fitAct = new QAction(tr("&Fittings..."), this);
+	fitAct = new QAction(tr("&Fittings..."), this);
 	fitAct->setWhatsThis("fit");
 	connect(fitAct, SIGNAL(triggered()),
 			this, SLOT(fit()));
 
-	QAction *setAct = new QAction(tr("&Settings..."), this);
+	setAct = new QAction(tr("&Settings..."), this);
 	setAct->setWhatsThis("set");
-#if QT_VERSION >= 0x040200
+#if QT_VERSION >= 0x040200 && defined(Q_OS_DARWIN)
 	setAct->setMenuRole(QAction::TextHeuristicRole);
 #endif
 	connect(setAct, SIGNAL(triggered()),
@@ -220,26 +231,29 @@ MainWindow::MainWindow(QWidget *parent)
 			this, SLOT(console(bool)));
 
 
-	QAction *whatsThisAct = new QAction(tr("What's &This?"), this);
+	whatsThisAct = new QAction(tr("What's &This?"), this);
 	whatsThisAct->setShortcut(tr("Shift+F1"));
 	whatsThisAct->setIcon(QIcon(":/images/contexthelp.png"));
 	connect(whatsThisAct, SIGNAL(triggered()),
 			this, SLOT(whatsThis()));
 
-	QAction *aboutAct = new QAction(tr("&About"), this);
-#if QT_VERSION >= 0x040200
+	aboutAct = new QAction(tr("&About"), this);
+#if QT_VERSION >= 0x040200 && defined(Q_OS_DARWIN)
 	aboutAct->setMenuRole(QAction::AboutRole);
 #endif
 	connect(aboutAct, SIGNAL(triggered()),
 			this, SLOT(about()));
 
-	QAction *aboutQtAct = new QAction(tr("About &Qt"), this);
-#if QT_VERSION >= 0x040200
+	aboutQtAct = new QAction(tr("About &Qt"), this);
+#if QT_VERSION >= 0x040200 && defined(Q_OS_DARWIN)
 	aboutQtAct->setMenuRole(QAction::AboutQtRole);
 #endif
 	connect(aboutQtAct, SIGNAL(triggered()),
 			QCoreApplication::instance(), SLOT(aboutQt()));
+}
 
+void MainWindow::createMenus()
+{
 	QMenu *fileMenu = menuBar()->addMenu(tr("&File"));
 	fileMenu->addAction(loadAct);
 	fileMenu->addAction(saveAct);
@@ -265,7 +279,10 @@ MainWindow::MainWindow(QWidget *parent)
 	helpMenu->addSeparator();
 	helpMenu->addAction(aboutAct);
 	helpMenu->addAction(aboutQtAct);
+}
 
+void MainWindow::createToolBars()
+{
 	toolBar = addToolBar(tr("Tool Bar"));
 	toolBar->addAction(loadAct);
 	toolBar->addAction(saveAct);
@@ -284,6 +301,8 @@ MainWindow::~MainWindow()
 
 void MainWindow::addData()
 {
+	// 関数が選択されていれば関数を追加し、
+	// ファイルが選択されていればファイルを追加する
 	bool isFunction = functionRadioButton->isChecked();
 	QLineEdit *lineEdit = isFunction ? functionEdit : filenameEdit;
 	QString data = lineEdit->text();
@@ -294,11 +313,13 @@ void MainWindow::addData()
 	plot->setFunction(isFunction);
 	isFunction ? plot->setFunction(data) : plot->setDataFile(data);
 	if (plotListWidget->currentRow() < 0) {
+		// リスト中に項目がないとき
 		plotListWidget->addItem(data);
 		plotListWidget->setCurrentRow(plotListWidget->count() - 1);
 
 		plotList.append(plot);
 	} else {
+		// 項目があるとき、選択されている項目の次に追加
 		int row = plotListWidget->currentRow() + 1;
 		plotListWidget->insertItem(row, data);
 		plotListWidget->setCurrentRow(row);
@@ -396,7 +417,6 @@ void MainWindow::save()
 
 void MainWindow::saveAs()
 {
-	// get filename
 	QString file = QFileDialog::getSaveFileName(this,
 			tr("Save under a file name") + " - " 
 			+ QCoreApplication::applicationName(),
@@ -409,7 +429,6 @@ void MainWindow::saveAs()
 
 void MainWindow::load()
 {
-	// get filename
 	QString file = QFileDialog::getOpenFileName(this,
 			tr("Open a file") + " - " + QCoreApplication::applicationName(),
 			currentFile); 
@@ -454,9 +473,13 @@ void MainWindow::set()
 
 void MainWindow::setPushButton()
 {
+	// 項目が一つでも選択されていたら、
+	// オプションボタンと削除ボタンを有効にする
 	bool isSelected = (plotListWidget->currentRow() >= 0);
 	optionPushButton->setEnabled(isSelected);
 	deletePushButton->setEnabled(isSelected);
+	// 選択された項目があり、複数の項目がリスト中にあれば、
+	// 上ボタンと下ボタンを有効にする
 	bool isMulti = isSelected && (plotListWidget->count() > 1);
 	upPushButton->setEnabled(isMulti);
 	downPushButton->setEnabled(isMulti);
@@ -502,21 +525,21 @@ void MainWindow::about()
 {
 	QMessageBox::about(this, tr("About %1")
 			.arg(QCoreApplication::applicationName()), 
-			"<h3>" + QCoreApplication::applicationName() + " 0.0.2</h3>"
+			"<h3>" + QCoreApplication::applicationName() + " 0.0.3</h3>"
 			"<p>" + QCoreApplication::applicationName() 
-			+ tr(": a GUI front end to gnuplot<br>"
-			"Copyright (C) 2007 Muneyuki Noguchi</p>"
-			"<p>This program is free software; you can redistribute it and/or "
-			"modify it under the terms of the GNU General Public License "
-			"as published by the Free Software Foundation; either version 2 "
-			"of the License, or (at your option) any later version.</p>"
-			"<p>This program is distributed in the hope that it will be useful, "
-			"but WITHOUT ANY WARRANTY; without even the implied warranty of "
-			"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the "
-			"GNU General Public License for more details.</p>"
-			"<p>You should have received a copy of the GNU General Public License "
-			"along with this program; if not, write to the Free Software "
-			"Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.</p>"));
+			+ tr(": a GUI front-end to gnuplot<br>"
+				"Copyright (C) 2007 Muneyuki Noguchi</p>"
+				"<p>This program is free software; you can redistribute it and/or "
+				"modify it under the terms of the GNU General Public License "
+				"as published by the Free Software Foundation; either version 2 "
+				"of the License, or (at your option) any later version.</p>"
+				"<p>This program is distributed in the hope that it will be useful, "
+				"but WITHOUT ANY WARRANTY; without even the implied warranty of "
+				"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the "
+				"GNU General Public License for more details.</p>"
+				"<p>You should have received a copy of the GNU General Public License "
+				"along with this program; if not, write to the Free Software "
+				"Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.</p>"));
 }
 
 void MainWindow::changeItem(QListWidgetItem *item)
@@ -534,6 +557,7 @@ void MainWindow::changeItem(QListWidgetItem *item)
 
 void MainWindow::closeEvent(QCloseEvent *event)
 {
+	// 一つでも項目がリスト中にあれば、終了させるか確認ダイアログを表示
 	if (plotListWidget->count() > 0) {
 		switch (QMessageBox::warning(this, tr("Confirmation") + " - "
 					+ QCoreApplication::applicationName(),
@@ -545,6 +569,7 @@ void MainWindow::closeEvent(QCloseEvent *event)
 			return;
 		}
 	}
+	// すべてのダイアログを閉じる
 	FitDialog::destroyInstance();
 	OptionDialog::destroyInstance();
 	RawCommandDialog::destroyInstance();
@@ -554,6 +579,7 @@ void MainWindow::closeEvent(QCloseEvent *event)
 
 void MainWindow::setAction()
 {
+	// チェックされている項目があるか調べる
 	bool isChecked = false;
 	for (int i = 0, j = plotListWidget->count(); i < j; i++) {
 		if (plotListWidget->item(i)->checkState() == Qt::Checked) {
