@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -22,7 +22,7 @@
 class Plot;
 class Process;
 
-#include <QMainWindow>
+#include <QtGui/QMainWindow>
 class QCloseEvent;
 class QLineEdit;
 class QListWidget;
@@ -30,12 +30,13 @@ class QListWidgetItem;
 class QPushButton;
 class QRadioButton;
 
+//! メインウィンドウ
 class MainWindow : public QMainWindow
 {
 	Q_OBJECT
 
 	public:
-		MainWindow(QWidget *parent = 0);
+		explicit MainWindow(QWidget *parent = 0);
 		~MainWindow();
 
 	private slots:
@@ -67,6 +68,9 @@ class MainWindow : public QMainWindow
 		MainWindow(const MainWindow &);
 		MainWindow &operator=(const MainWindow &);
 
+		void createActions();
+		void createMenus();
+		void createToolBars();
 		void closeEvent(QCloseEvent *event);
 		void setAction();
 		Process *process;
@@ -84,9 +88,19 @@ class MainWindow : public QMainWindow
 		QPushButton *deletePushButton;
 		QListWidget *plotListWidget;
 		QToolBar *toolBar;
+		QAction *loadAct;
+		QAction *saveAct;
+		QAction *saveAsAct;
+		QAction *quitAct;
 		QAction *plotAct;
 		QAction *splotAct;
+		QAction *rawCommandAct;
+		QAction *fitAct;
+		QAction *setAct;
 		QAction *toolBarAct;
 		QAction *consoleAct;
+		QAction *whatsThisAct;
+		QAction *aboutAct;
+		QAction *aboutQtAct;
 };
 #endif // MAIN_WINDOW_INCLUDED
