@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -25,26 +25,32 @@
 #include "BarOptionWidget.h"
 #include "BoxWidthOptionWidget.h"
 #include "DummyOptionWidget.h"
+#include "EncodingOptionWidget.h"
 #include "FormatOptionWidget.h"
 #include "GridOptionWidget.h"
 #include "KeyOptionWidget.h"
 #include "LogScaleOptionWidget.h"
+#include "MappingOptionWidget.h"
 #include "MAxisTicsOptionWidget.h"
 #include "OutputOptionWidget.h"
+#include "ParametricOptionWidget.h"
+#include "SamplesOptionWidget.h"
 #include "SizeOptionWidget.h"
 #include "TerminalOptionWidget.h"
 #include "TitleOptionWidget.h"
+#include "ViewOptionWidget.h"
 
-#include <QCloseEvent>
-#include <QCoreApplication>
-#include <QListWidget>
-#include <QListWidgetItem>
-#include <QHBoxLayout>
-#include <QMessageBox>
-#include <QPushButton>
-#include <QSplitter>
-#include <QStackedWidget>
-#include <QVBoxLayout>
+#include <QtCore/QCoreApplication>
+#include <QtGui/QCloseEvent>
+#include <QtGui/QListWidget>
+#include <QtGui/QListWidgetItem>
+#include <QtGui/QHBoxLayout>
+#include <QtGui/QMessageBox>
+#include <QtGui/QPushButton>
+#include <QtGui/QScrollArea>
+#include <QtGui/QSplitter>
+#include <QtGui/QStackedWidget>
+#include <QtGui/QVBoxLayout>
 
 OptionDialog *OptionDialog::instance_ = 0;
 
@@ -79,15 +85,20 @@ OptionDialog::OptionDialog(QWidget *parent)
 	pagesStackedWidget->addWidget(new BarOptionWidget);
 	pagesStackedWidget->addWidget(new BoxWidthOptionWidget);
 	pagesStackedWidget->addWidget(new DummyOptionWidget);
+	pagesStackedWidget->addWidget(new EncodingOptionWidget);
 	pagesStackedWidget->addWidget(new FormatOptionWidget);
 	pagesStackedWidget->addWidget(new GridOptionWidget);
 	pagesStackedWidget->addWidget(new KeyOptionWidget);
 	pagesStackedWidget->addWidget(new LogScaleOptionWidget);
+	pagesStackedWidget->addWidget(new MappingOptionWidget);
 	pagesStackedWidget->addWidget(new MAxisTicsOptionWidget);
 	pagesStackedWidget->addWidget(new OutputOptionWidget);
+	pagesStackedWidget->addWidget(new ParametricOptionWidget);
+	pagesStackedWidget->addWidget(new SamplesOptionWidget);
 	pagesStackedWidget->addWidget(new SizeOptionWidget);
 	pagesStackedWidget->addWidget(new TerminalOptionWidget);
 	pagesStackedWidget->addWidget(new TitleOptionWidget);
+	pagesStackedWidget->addWidget(new ViewOptionWidget);
 
 	const int count = pagesStackedWidget->count();
 	initBitArray.resize(count);
@@ -104,6 +115,12 @@ OptionDialog::OptionDialog(QWidget *parent)
 	// FIXME
 	contentsListWidget->setCurrentRow(1);
 	contentsListWidget->setCurrentRow(0);
+
+	QScrollArea *scrollArea = new QScrollArea;
+	scrollArea->setWidget(pagesStackedWidget);
+	scrollArea->setWidgetResizable(true);
+	scrollArea->setFrameShadow(QFrame::Plain);
+	scrollArea->setFrameShape(QFrame::NoFrame);
 	
 	QFrame *lineFrame = new QFrame;
 	lineFrame->setFrameShape(QFrame::HLine);
@@ -141,7 +158,7 @@ OptionDialog::OptionDialog(QWidget *parent)
 	buttonLayout->addWidget(rejectPushButton);
 
 	QVBoxLayout *pagesLayout = new QVBoxLayout;
-	pagesLayout->addWidget(pagesStackedWidget);
+	pagesLayout->addWidget(scrollArea);
 	pagesLayout->addWidget(lineFrame);
 	pagesLayout->addLayout(buttonLayout);
 
@@ -173,6 +190,7 @@ void OptionDialog::apply()
 
 void OptionDialog::reject()
 {
+	// 変更を破棄
 	if (isWindowModified()) {
 		discard(qobject_cast<OptionWidget *>(pagesStackedWidget->
 					currentWidget()));
@@ -203,6 +221,7 @@ void OptionDialog::changePage(QListWidgetItem *current,
 	if (!current) {
 		current = previous;
 	} else if (isWindowModified()) {
+		// 設定を保存せずに、別の項目に移動しようとした場合に確認する
 		switch (QMessageBox::warning(this, tr("Unsaved Changes") + " - "
 					+ QCoreApplication::applicationName(),
 					tr("There are unsaved changes in this option.\n"
@@ -228,6 +247,7 @@ void OptionDialog::changePage(QListWidgetItem *current,
 		}
 	}
 	int index = contentsListWidget->row(current);
+	// 以前に表示した項目でなければ、ウィジェットを初期化する
 	if (!initBitArray.at(index)) {
 		OptionWidget *optionWidget 
 			= qobject_cast<OptionWidget *>(pagesStackedWidget->widget(index));
@@ -249,6 +269,7 @@ void OptionDialog::setModified()
 
 void OptionDialog::closeEvent(QCloseEvent *e)
 {
+	// ダイアログが閉じられたときに、設定を破棄する
 	if (isWindowModified()) {
 		discard(qobject_cast<OptionWidget *>(pagesStackedWidget->
 					currentWidget()));
