@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -21,14 +21,15 @@
 
 class OptionWidget;
 
-#include <QBitArray>
-#include <QDialog>
+#include <QtCore/QBitArray>
+#include <QtGui/QDialog>
 class QCloseEvent;
 class QListWidget;
 class QListWidgetItem;
 class QDialog;
 class QStackedWidget;
 
+//! 設定ダイアログ (Singleton)
 class OptionDialog : public QDialog
 {
 	Q_OBJECT
@@ -38,14 +39,23 @@ class OptionDialog : public QDialog
 		static void destroyInstance();
 
     private slots:
+		//! 設定を適用してダイアログを閉じる
 		void accept();
+		//! 設定を適用する
 		void apply();
+		//! 設定を破棄してダイアログを閉じる
 		void reject();
+		//! 設定を初期化する
 		void init();
         void changePage(QListWidgetItem *current, QListWidgetItem *previous);
+		//! 設定に変更が加えられたことにする
 		void setModified();
 
 	signals:
+		//! コマンドを実行する
+		/*!
+		 * \param command 実行するコマンド
+		 */
 		void executed(const QString &command);
 
 	private:
@@ -54,11 +64,13 @@ class OptionDialog : public QDialog
 		OptionDialog(const OptionDialog &);
 		OptionDialog &operator=(const OptionDialog &);
 
+		//! 設定を破棄する
 		void discard(OptionWidget *optionWidget);
 		void closeEvent(QCloseEvent *e);
 		static OptionDialog *instance_;
 		QListWidget *contentsListWidget;
 		QStackedWidget *pagesStackedWidget;
+		//! 設定項目のウィジェットが初期化済みか調べるのに使う配列
 		QBitArray initBitArray;
 };
 
