@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -23,12 +23,12 @@
 #include "PlotStyleWidget.h"
 #include "PlotTitleWidget.h"
 
-#include <QCoreApplication>
-#include <QListWidget>
-#include <QPushButton>
-#include <QSplitter>
-#include <QStackedWidget>
-#include <QVBoxLayout>
+#include <QtCore/QCoreApplication>
+#include <QtGui/QListWidget>
+#include <QtGui/QPushButton>
+#include <QtGui/QSplitter>
+#include <QtGui/QStackedWidget>
+#include <QtGui/QVBoxLayout>
 
 PlotOptionDialog::PlotOptionDialog(QWidget *parent)
 : QDialog(parent)
