@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -25,28 +25,37 @@ class PlotOthersWidget;
 class PlotStyleWidget;
 class PlotTitleWidget;
 
-#include <QDialog>
+#include <QtGui/QDialog>
 class QListWidget;
 class QListWidgetItem;
 class QStackedWidget;
 
+//! plot コマンドのオプションを設定するダイアログ
 class PlotOptionDialog : public QDialog
 {
 	Q_OBJECT
 
 	public:
-		PlotOptionDialog(QWidget *parent = 0);
+		explicit PlotOptionDialog(QWidget *parent = 0);
 
 		void setPlot(Plot &plot);
 
 	private slots:
+		//! 設定を保存して、ダイアログを閉じる
 		void accept();
+		//! 設定を保存する
 		void apply();
+		//! 二次元のプロットをする
 		void plot();
+		//! 三次元のプロットをする
 		void splot();
 		void changePage(QListWidgetItem *current, QListWidgetItem *previous);
 
 	signals:
+		//! コマンドを実行する
+		/*!
+		 * \param 実行するコマンド
+		 */
 		void executed(const QString &);
 
 	private:
@@ -55,6 +64,7 @@ class PlotOptionDialog : public QDialog
 		PlotOptionDialog &operator=(const PlotOptionDialog &);
 
 		void setPlotOption(Plot &plot);
+		//! オプションを設定する項目に対応するオブジェクト
 		Plot *plot_;
 		QStackedWidget *pagesStackedWidget;
 		QListWidget *contentsListWidget;
