@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -21,22 +21,27 @@
 
 class ConsoleDialog;
 
-#include <QObject>
+#include <QtCore/QObject>
 class QProcess;
 class QString;
 
+//! gnuplot のプロセスを扱うクラス
 class Process : public QObject
 {
 	Q_OBJECT
 
 	public:
-		Process(QObject *parent = 0);
+		explicit Process(QObject *parent = 0);
 
 		void closeDialog();
 		void setDialogVisible(bool visible);
 		bool isDialogVisible();
 
 	public slots:
+		//! コマンドを実行する
+		/*!
+		 * \param command 実行するコマンド
+		 */
 		void execute(const QString &command);
 
 	private slots:
@@ -47,7 +52,16 @@ class Process : public QObject
 		Process(const Process &);
 		Process &operator=(const Process &);
 
+		//! gnuplot のプロセスを起動する
+		/*!
+		 * \return 起動に成功したら true
+		 */
 		bool startProcess();
+		//! 起動できるか調べる
+		/*!
+		 * \param path gnuplot のパス
+		 * \return 起動できたら true
+		 */
 		bool canStart(const QString &path);
 
 		QProcess *process;
