@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -18,12 +18,11 @@
  */
 #include "RawCommandDialog.h"
 
-#include <QCoreApplication>
-#include <QHBoxLayout>
-#include <QPushButton>
-#include <QStyle>
-#include <QTextEdit>
-#include <QVBoxLayout>
+#include <QtCore/QCoreApplication>
+#include <QtGui/QHBoxLayout>
+#include <QtGui/QPushButton>
+#include <QtGui/QTextEdit>
+#include <QtGui/QVBoxLayout>
 
 RawCommandDialog *RawCommandDialog::instance_ = 0;
 
@@ -84,5 +83,6 @@ void RawCommandDialog::accept()
 
 void RawCommandDialog::setButton()
 {
+	// テキストエディット内が空でなければ、実行ボタンを有効にする
 	execPushButton->setEnabled(!rawTextEdit->toPlainText().isEmpty());
 }
