@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -19,9 +19,10 @@
 #ifndef RAW_COMMAND_DIALOG_INCLUDED
 #define RAW_COMMAND_DIALOG_INCLUDED
 
-#include <QDialog>
+#include <QtGui/QDialog>
 class QTextEdit;
 
+//! コマンドをそのまま gnuplot に対して送るためのダイアログ (Singleton)
 class RawCommandDialog : public QDialog
 {
 	Q_OBJECT
@@ -34,6 +35,10 @@ class RawCommandDialog : public QDialog
 		void setButton();
 
 	signals:
+		//! コマンドを実行する
+		/*!
+		 * \param command 実行するコマンド
+		 */
 		void executed(const QString &command);
 
 	private:
