@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -18,15 +18,15 @@
  */
 #include "FitBasicWidget.h"
 
-#include <QCoreApplication>
-#include <QLabel>
-#include <QLineEdit>
-#include <QFileDialog>
-#include <QGroupBox>
-#include <QGridLayout>
-#include <QPushButton>
-#include <QRadioButton>
-#include <QVBoxLayout>
+#include <QtCore/QCoreApplication>
+#include <QtGui/QLabel>
+#include <QtGui/QLineEdit>
+#include <QtGui/QFileDialog>
+#include <QtGui/QGroupBox>
+#include <QtGui/QGridLayout>
+#include <QtGui/QPushButton>
+#include <QtGui/QRadioButton>
+#include <QtGui/QVBoxLayout>
 
 FitBasicWidget::FitBasicWidget(QWidget *parent)
 : QWidget(parent)
