@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -18,11 +18,11 @@
  */
 #include "FitOthersWidget.h"
 
-#include <QDoubleSpinBox>
-#include <QLabel>
-#include <QGroupBox>
-#include <QGridLayout>
-#include <QVBoxLayout>
+#include <QtGui/QDoubleSpinBox>
+#include <QtGui/QLabel>
+#include <QtGui/QGroupBox>
+#include <QtGui/QGridLayout>
+#include <QtGui/QVBoxLayout>
 
 #include <cmath> // pow(), floor()
 
