@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -19,10 +19,10 @@
 #include "FitRangeWidget.h"
 #include "FitRange.h"
 
-#include <QLabel>
-#include <QLineEdit>
-#include <QGroupBox>
-#include <QVBoxLayout>
+#include <QtGui/QLabel>
+#include <QtGui/QLineEdit>
+#include <QtGui/QGroupBox>
+#include <QtGui/QVBoxLayout>
 
 FitRangeWidget::FitRangeWidget(QWidget *parent)
 : QWidget(parent)
