@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -31,7 +31,7 @@ class AnglesOptionWidget : public OptionWidget
 	Q_OBJECT
 
 	public:
-		AnglesOptionWidget(QWidget *parent = 0);
+		explicit AnglesOptionWidget(QWidget *parent = 0);
 		~AnglesOptionWidget();
 
 		void construct();
@@ -48,4 +48,4 @@ class AnglesOptionWidget : public OptionWidget
 		QRadioButton *degreesRadioButton;
 		QRadioButton *radiansRadioButton;
 };
-#endif // SIZE_OPTION_WIDGET_INCLUDED
+#endif // ANGLES_OPTION_WIDGET_INCLUDED
