@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -19,10 +19,10 @@
 #include "BoxWidthOptionWidget.h"
 #include "BoxWidth.h"
 
-#include <QCheckBox>
-#include <QDoubleSpinBox>
-#include <QHBoxLayout>
-#include <QVBoxLayout>
+#include <QtGui/QCheckBox>
+#include <QtGui/QDoubleSpinBox>
+#include <QtGui/QHBoxLayout>
+#include <QtGui/QVBoxLayout>
 
 BoxWidthOptionWidget::BoxWidthOptionWidget(QWidget *parent)
 : OptionWidget(parent), boxWidth(0)
