@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -19,9 +19,9 @@
 #include "DummyOptionWidget.h"
 #include "Dummy.h"
 
-#include <QGridLayout>
-#include <QLabel>
-#include <QLineEdit>
+#include <QtGui/QGridLayout>
+#include <QtGui/QLabel>
+#include <QtGui/QLineEdit>
 
 DummyOptionWidget::DummyOptionWidget(QWidget *parent)
 : OptionWidget(parent), dummy(0)
