@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -30,7 +30,7 @@ class DummyOptionWidget : public OptionWidget
 	Q_OBJECT
 
 	public:
-		DummyOptionWidget(QWidget *parent = 0);
+		explicit DummyOptionWidget(QWidget *parent = 0);
 		~DummyOptionWidget();
 
 		void construct();
