@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -23,7 +23,7 @@
 
 class Format;
 
-#include <QList>
+#include <QtCore/QList>
 class QCheckBox;
 class QLineEdit;
 
@@ -32,7 +32,7 @@ class FormatOptionWidget : public OptionWidget
 	Q_OBJECT
 
 	public:
-		FormatOptionWidget(QWidget *parent = 0);
+		explicit FormatOptionWidget(QWidget *parent = 0);
 		~FormatOptionWidget();
 
 		void construct();
