@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -23,7 +23,7 @@
 
 class Grid;
 
-#include <QList>
+#include <QtCore/QList>
 class QCheckBox;
 
 class GridOptionWidget : public OptionWidget
@@ -31,7 +31,7 @@ class GridOptionWidget : public OptionWidget
 	Q_OBJECT
 
 	public:
-		GridOptionWidget(QWidget *parent = 0);
+		explicit GridOptionWidget(QWidget *parent = 0);
 		~GridOptionWidget();
 
 		void construct();
