@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -19,18 +19,19 @@
 #include "KeyOptionWidget.h"
 #include "Key.h"
 
-#include <QCheckBox>
-#include <QComboBox>
-#include <QDoubleSpinBox>
-#include <QGridLayout>
-#include <QGroupBox>
-#include <QLabel>
-#include <QLineEdit>
-#include <QRadioButton>
-#include <QSpinBox>
-#include <QStackedWidget>
-#include <QTabWidget>
-#include <QVBoxLayout>
+#include <QtCore/QCoreApplication>
+#include <QtGui/QCheckBox>
+#include <QtGui/QComboBox>
+#include <QtGui/QDoubleSpinBox>
+#include <QtGui/QGridLayout>
+#include <QtGui/QGroupBox>
+#include <QtGui/QLabel>
+#include <QtGui/QLineEdit>
+#include <QtGui/QRadioButton>
+#include <QtGui/QSpinBox>
+#include <QtGui/QStackedWidget>
+#include <QtGui/QTabWidget>
+#include <QtGui/QVBoxLayout>
 
 #include <cmath> // pow()
 
@@ -59,11 +60,10 @@ void KeyOptionWidget::construct()
 	connect(keyCheckBox, SIGNAL(toggled(bool)),
 			this, SIGNAL(modified()));
 
-	for (int i = 0; !Key::POSITION[i].isEmpty(); i++) {
+	for (int i = 0; Key::POSITION[i][0]; i++) {
 		QCheckBox *positionCheckBox = new QCheckBox;
-		positionCheckBox->setText(Key::POSITION[i]);
-		connect(positionCheckBox, SIGNAL(toggled(bool)),
-				this, SLOT(validatePosition()));
+		positionCheckBox->setText(QCoreApplication::translate(
+					"Key", Key::POSITION[i]));
 		connect(positionCheckBox, SIGNAL(toggled(bool)),
 				this, SIGNAL(modified()));
 		positionCheckBoxList.append(positionCheckBox);
@@ -71,7 +71,7 @@ void KeyOptionWidget::construct()
 
 	const int num = 3;
 	QGridLayout *cornerLayout = new QGridLayout;
-	for (int i = 0; !Key::POSITION[i].isEmpty(); i++) {
+	for (int i = 0; Key::POSITION[i][0]; i++) {
 		cornerLayout->addWidget(positionCheckBoxList[i], i / num, i % num);
 	}
 	cornerLayout->addItem(new QSpacerItem(40, 20, 
@@ -80,11 +80,10 @@ void KeyOptionWidget::construct()
 	QWidget *cornerWidget = new QWidget;
 	cornerWidget->setLayout(cornerLayout);
 
-	const int LIMIT = 32767;
 	for (int i = 0; !Key::AXIS[i].isEmpty(); i++) {
 		QDoubleSpinBox *positionDoubleSpinBox = new QDoubleSpinBox;
-		positionDoubleSpinBox->setMaximum(LIMIT);
-		positionDoubleSpinBox->setMinimum(-LIMIT);
+		positionDoubleSpinBox->setMaximum(std::numeric_limits<double>::max());
+		positionDoubleSpinBox->setMinimum(-std::numeric_limits<double>::max());
 		connect(positionDoubleSpinBox, SIGNAL(valueChanged(double)),
 				this, SIGNAL(modified()));
 		positionDoubleSpinBoxList.append(positionDoubleSpinBox);
@@ -282,7 +281,7 @@ void KeyOptionWidget::apply()
 	case 0:
 		{
 			int pos = 0;
-			for (int i = 0; !Key::POSITION[i].isEmpty(); i++) {
+			for (int i = 0; Key::POSITION[i][0]; i++) {
 				if (positionCheckBoxList.at(i)->isChecked()) {
 					pos |= static_cast<int>(
 							std::pow(static_cast<double>(2), i));
@@ -315,23 +314,13 @@ void KeyOptionWidget::apply()
 	emit executed(key->command());
 }
 
-void KeyOptionWidget::validatePosition()
-{
-	for (int i = 0; !Key::POSITION[i].isEmpty(); i++) {
-		if (positionCheckBoxList.at(i)->isChecked()) {
-			return;
-		}
-	}
-	positionComboBox->setCurrentIndex(1);
-}
-
 void KeyOptionWidget::setWidget()
 {
 	keyCheckBox->setChecked(key->isOn());
 
 	int pos = key->position();
 	positionComboBox->setCurrentIndex(pos == 0);
-	for (int i = 0; !Key::POSITION[i].isEmpty(); i++) {
+	for (int i = 0; Key::POSITION[i][0]; i++) {
 		positionCheckBoxList[i]->setChecked(pos 
 				& static_cast<int>(std::pow(static_cast<double>(2), i)));
 	}
