@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -23,7 +23,7 @@
 
 class Key;
 
-#include <QList>
+#include <QtCore/QList>
 class QCheckBox;
 class QComboBox;
 class QDoubleSpinBox;
@@ -38,14 +38,11 @@ class KeyOptionWidget : public OptionWidget
 	Q_OBJECT
 
 	public:
-		KeyOptionWidget(QWidget *parent = 0);
+		explicit KeyOptionWidget(QWidget *parent = 0);
 		~KeyOptionWidget();
 
 		void construct();
 
-	private slots:
-		void validatePosition();
-
 	private:
 		// don't implement these
 		KeyOptionWidget(const KeyOptionWidget &);
