@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -19,9 +19,9 @@
 #include "LogScaleOptionWidget.h"
 #include "LogScale.h"
 
-#include <QCheckBox>
-#include <QGridLayout>
-#include <QLineEdit>
+#include <QtGui/QCheckBox>
+#include <QtGui/QGridLayout>
+#include <QtGui/QLineEdit>
 
 LogScaleOptionWidget::LogScaleOptionWidget(QWidget *parent)
 : OptionWidget(parent), logScale(0)
