@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -19,22 +19,31 @@
 #ifndef OPTION_WIDGET_INCLUDED
 #define OPTION_WIDGET_INCLUDED
 
-#include <QWidget>
+#include <QtGui/QWidget>
 
+//! set コマンドのオプションを扱うウィジェット
 class OptionWidget : public QWidget
 {
 	Q_OBJECT
 
 	public:
-		OptionWidget(QWidget *parent = 0);
+		explicit OptionWidget(QWidget *parent = 0);
 		virtual ~OptionWidget();
 
+		//! ウィジェット内の要素を構築
 		virtual void construct() = 0;
+		//! ウィジェットを初期化
 		virtual void init() = 0;
+		//! ウィジェットの状態をもとにコマンドを実行
 		virtual void apply() = 0;
+		//! ウィジェットの状態の変化を破棄
 		void discard();
 
 	signals:
+		//! コマンドを実行する
+		/*!
+		 * \param command 実行するコマンド
+		 */
 		void executed(const QString &command);
 		void modified();
 
