@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -19,13 +19,13 @@
 #include "OutputOptionWidget.h"
 #include "Output.h"
 
-#include <QCoreApplication>
-#include <QCheckBox>
-#include <QLineEdit>
-#include <QFileDialog>
-#include <QHBoxLayout>
-#include <QPushButton>
-#include <QVBoxLayout>
+#include <QtCore/QCoreApplication>
+#include <QtGui/QCheckBox>
+#include <QtGui/QLineEdit>
+#include <QtGui/QFileDialog>
+#include <QtGui/QHBoxLayout>
+#include <QtGui/QPushButton>
+#include <QtGui/QVBoxLayout>
 
 OutputOptionWidget::OutputOptionWidget(QWidget *parent)
 : OptionWidget(parent), output(0)
