@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -19,10 +19,10 @@
 #include "SizeOptionWidget.h"
 #include "Size.h"
 
-#include <QCheckBox>
-#include <QDoubleSpinBox>
-#include <QLabel>
-#include <QGridLayout>
+#include <QtGui/QCheckBox>
+#include <QtGui/QDoubleSpinBox>
+#include <QtGui/QLabel>
+#include <QtGui/QGridLayout>
 
 SizeOptionWidget::SizeOptionWidget(QWidget *parent)
 : OptionWidget(parent), size(0)
