@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -31,7 +31,7 @@ class SizeOptionWidget : public OptionWidget
 	Q_OBJECT
 
 	public:
-		SizeOptionWidget(QWidget *parent = 0);
+		explicit SizeOptionWidget(QWidget *parent = 0);
 		~SizeOptionWidget();
 
 		void construct();
