@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -23,16 +23,17 @@
 #include "TerminalPbmOptionWidget.h"
 #include "TerminalPostScriptOptionWidget.h"
 
-#include <QComboBox>
-#include <QLabel>
-#include <QHBoxLayout>
-#include <QPushButton>
-#include <QStackedWidget>
-#include <QVBoxLayout>
+#include <QtGui/QComboBox>
+#include <QtGui/QLabel>
+#include <QtGui/QHBoxLayout>
+#include <QtGui/QPushButton>
+#include <QtGui/QScrollArea>
+#include <QtGui/QStackedWidget>
+#include <QtGui/QVBoxLayout>
 
 const QString TerminalOptionWidget::TERMINAL[] = {
 	"aifm",
-#ifdef Q_OS_MACX
+#ifdef Q_OS_DARWIN
 	"aqua",
 #endif
 	"cgm", "corel", "dumb", "dxf", "eepic", "emf", "emtex", "epslatex",
@@ -96,6 +97,12 @@ void TerminalOptionWidget::construct()
 		changeTerminal(index);
 	}
 
+	QScrollArea *scrollArea = new QScrollArea;
+	scrollArea->setWidget(typeStackedWidget);
+	scrollArea->setWidgetResizable(true);
+	scrollArea->setFrameShadow(QFrame::Plain);
+	scrollArea->setFrameShape(QFrame::NoFrame);
+
 	QHBoxLayout *buttonLayout = new QHBoxLayout;
 	buttonLayout->addStretch();
 	buttonLayout->addWidget(initPushButton);
@@ -106,8 +113,7 @@ void TerminalOptionWidget::construct()
 
 	QVBoxLayout *mainLayout = new QVBoxLayout;
 	mainLayout->addLayout(listLayout);
-	mainLayout->addWidget(typeStackedWidget);
-	mainLayout->addStretch();
+	mainLayout->addWidget(scrollArea);
 	mainLayout->addLayout(buttonLayout);
 
 	setLayout(mainLayout);
