@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -23,7 +23,7 @@
 
 class Terminal;
 
-#include <QBitArray>
+#include <QtCore/QBitArray>
 class QComboBox;
 class QPushButton;
 class QStackedWidget;
@@ -33,7 +33,7 @@ class TerminalOptionWidget : public OptionWidget
 	Q_OBJECT
 
 	public:
-		TerminalOptionWidget(QWidget *parent = 0);
+		explicit TerminalOptionWidget(QWidget *parent = 0);
 		~TerminalOptionWidget();
 
 		void construct();
