@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -26,7 +26,7 @@ class TerminalLatexOptionWidget : public TerminalLatexEmtexOptionWidget
 	Q_OBJECT
 
 	public:
-		TerminalLatexOptionWidget(QWidget *parent = 0);
+		explicit TerminalLatexOptionWidget(QWidget *parent = 0);
 
 	private:
 		// don't implement these
