@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -19,13 +19,13 @@
 #include "PlotModifierWidget.h"
 #include "PlotModifier.h"
 
-#include <QCheckBox>
-#include <QComboBox>
-#include <QLabel>
-#include <QLineEdit>
-#include <QGridLayout>
-#include <QSpinBox>
-#include <QVBoxLayout>
+#include <QtGui/QCheckBox>
+#include <QtGui/QComboBox>
+#include <QtGui/QLabel>
+#include <QtGui/QLineEdit>
+#include <QtGui/QGridLayout>
+#include <QtGui/QSpinBox>
+#include <QtGui/QVBoxLayout>
 
 PlotModifierWidget::PlotModifierWidget(QWidget *parent)
 : QWidget(parent)
