@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -19,10 +19,10 @@
 #include "PlotOthersWidget.h"
 #include "Plot.h"
 
-#include <QComboBox>
-#include <QGroupBox>
-#include <QHBoxLayout>
-#include <QVBoxLayout>
+#include <QtGui/QComboBox>
+#include <QtGui/QGroupBox>
+#include <QtGui/QHBoxLayout>
+#include <QtGui/QVBoxLayout>
 
 PlotOthersWidget::PlotOthersWidget(QWidget *parent)
 : QWidget(parent)
