@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -19,7 +19,7 @@
 #ifndef PLOT_OTHERS_WIDGET_INCLUDED
 #define PLOT_OTHERS_WIDGET_INCLUDED
 
-#include <QWidget>
+#include <QtGui/QWidget>
 class QComboBox;
 class QGroupBox;
 
@@ -28,7 +28,7 @@ class PlotOthersWidget : public QWidget
 	Q_OBJECT
 
 	public:
-		PlotOthersWidget(QWidget *parent = 0);
+		explicit PlotOthersWidget(QWidget *parent = 0);
 
 		void setPlotAxis(int axis);
 		int plotAxis() const;
