@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -19,9 +19,9 @@
 #include "PlotTitleWidget.h"
 #include "PlotTitle.h"
 
-#include <QLineEdit>
-#include <QGridLayout>
-#include <QRadioButton>
+#include <QtGui/QLineEdit>
+#include <QtGui/QGridLayout>
+#include <QtGui/QRadioButton>
 
 PlotTitleWidget::PlotTitleWidget(QWidget *parent)
 : QWidget(parent)
