@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -21,7 +21,7 @@
 
 class PlotTitle;
 
-#include <QWidget>
+#include <QtGui/QWidget>
 class QLineEdit;
 class QRadioButton;
 
@@ -30,7 +30,7 @@ class PlotTitleWidget : public QWidget
 	Q_OBJECT
 
 	public:
-		PlotTitleWidget(QWidget *parent = 0);
+		explicit PlotTitleWidget(QWidget *parent = 0);
 
 		void setPlotTitle(const PlotTitle &plotTitle);
 		PlotTitle plotTitle() const;
