@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -18,7 +18,7 @@
  */
 #include "AxisData.h"
 
-#include <QStringList>
+#include <QtCore/QStringList>
 
 const QString AxisData::AXIS[] = {
 	"x", "y", "z", "x2", "y2", "cb", ""
