@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -21,9 +21,10 @@
 
 #include "Option.h"
 
-#include <QList>
-#include <QString>
+#include <QtCore/QList>
+#include <QtCore/QString>
 
+//! set key コマンド
 class Key : public Option
 {
 	public:
@@ -76,8 +77,10 @@ class Key : public Option
 
 		QString command() const;
 
+		//! 軸
 		static const QString AXIS[];
-		static const QString POSITION[];
+		//! 凡例の位置
+		static const char * const POSITION[];
 
 	private:
 		static const int DEFAULT_LINE_TYPE = -2;
