@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -21,9 +21,10 @@
 
 #include "Option.h"
 
-#include <QList>
-#include <QString>
+#include <QtCore/QList>
+#include <QtCore/QString>
 
+//! set m{axis}tics コマンド
 class MAxisTics : public Option
 {
 	public:
@@ -37,6 +38,7 @@ class MAxisTics : public Option
 
 		QString command() const;
 
+		//! 軸
 		static const QString AXIS[];
 	private:
 		QList<bool> defaultList;
