@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -26,7 +26,7 @@ Terminal::Terminal() : status(TERMINAL)
 	if (gnuTerm) {
 		terminalType_ = gnuTerm;
 	} else {
-#if defined(Q_OS_MACX)
+#if defined(Q_OS_DARWIN)
 		terminalType_ = "aqua";
 #elif defined(Q_OS_UNIX)
 		terminalType_ = "x11";
