@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -21,8 +21,9 @@
 
 #include "Option.h"
 
-#include <QString>
+#include <QtCore/QString>
 
+//! set terminal コマンド
 class Terminal : public Option
 {
 	public:
