@@ -1,5 +1,5 @@
 /*
- * Cueplot: a GUI front end to gnuplot
+ * Cueplot: a GUI front-end to gnuplot
  * Copyright (C) 2007 Muneyuki Noguchi
  *
  * This program is free software; you can redistribute it and/or
@@ -23,6 +23,7 @@
 
 class QString;
 
+//! set terminal pbm コマンド
 class TerminalPbm : public Terminal
 {
 	public:
@@ -34,6 +35,11 @@ class TerminalPbm : public Terminal
 		void setMode(int mode);
 		int mode() const;
 
+		//! フォントのサイズ
+		static const char * const FONT_SIZE[];
+		//! モード（色）
+		static const char * const MODE[];
+
 	private:
 		QString terminalOption() const;
 		int fontSize_;
